"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const path = require("path");
const fs = require("fs-extra");
const defaultAPI = "https://api.framer.com";
exports.buildProjectConfig = argv => {
    // If a project path is specified, change process dir to that path
    // This is a workaround for a publish bug that causes builds
    // to fail when the script is run outside the project
    if (argv._[1]) {
        const projectPath = path.resolve(argv._[1]);
        // Confirm path exists
        if (!fs.pathExistsSync(projectPath)) {
            throw new Error(`The specified "${argv._[1]}" project does not exist.`);
        }
        // Confirm that the path is to a directory
        const stat = fs.statSync(projectPath);
        if (!stat.isDirectory()) {
            throw new Error("The project must be folder backed.");
        }
        process.chdir(projectPath);
    }
    const config = {
        api: argv.api || defaultAPI,
        // Command is always run from inside project
        projectPath: process.cwd(),
        cachePath: "/tmp/framer",
        yarnLinkFolder: "/tmp/framer-yarn-link-folder",
        token: process.env.FRAMER_TOKEN,
    };
    return config;
};
exports.buildAuthenticationConfig = argv => {
    const config = {
        api: argv.api || defaultAPI,
        email: argv._[1],
    };
    return config;
};
exports.buildPublishConfig = argv => {
    return {
        api: argv.api || defaultAPI,
        token: process.env.FRAMER_TOKEN,
        newName: argv.new,
        isNewArgSet: !!(argv.new && typeof argv.new === "string" && argv.new.trim()),
        isPublic: argv.public,
        isPrivate: !argv.public,
        disablePrompts: argv.yes,
    };
};
