#!/usr/bin/env node
"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const logger_1 = require("../logger");
logger_1.configure({ output: "debug" });
const package_1 = require("./package");
const interface_1 = require("./interface");
const handleError_1 = require("./handleError");
const commands = require("./commands");
const main = () => __awaiter(this, void 0, void 0, function* () {
    interface_1.setProcessTitle("Framer Project");
    // Check that the latest version of the CLI is being ran
    yield package_1.checkIfOutOfDate();
    // Command is treated specially when parsing argv
    const { command, argv, help } = interface_1.parseArgv();
    // Terminate early if command does not exist
    if (!(command in commands)) {
        interface_1.printUsage();
        // Terminate with an error code
        process.exit(1);
    }
    // Print usage for a specific command
    if (commands[command] && help) {
        interface_1.printUsage(command);
        process.exit();
    }
    // Errors will be handled by the `main` Promise catch
    return commands[command](argv);
});
// Terminate the process after command completes
main().then(() => process.exit(), error => handleError_1.handleError(error.message || error));
